#! /bin/sh
#
# Note that we have to convert cases of double quotes in the
# amigaguide @{...} output, and also in @node lines, to single
# quotes, since it confuses amigaguide and there doesn't seem to
# be any way to escape them.

tmpd=`date +%j%H%M%S`
tmp1="/tmp/sh1-$tmpd"
tmp2="/tmp/sh2-$tmpd"
tmp3="/tmp/sh3-$tmpd"
tmp4="/tmp/sh4-$tmpd"

volname=`pwd | sed -e 's%^/%%' -e 's%/.*%%'`

# Extract the .aminet-dir fields from each Product-Info file, sort them
# uniq them, and generate a list of categories that covers all the 
# product info files.

pitool -b -F "%A\n" -f - - <$1 | sed "s:/.*::" | sort -f | uniq >$tmp2

# Build the root node.

cat << EOF
@database Contents
@author "Amiga Library Services"
@(c) "Copyright  1995 Amiga Library Services"
@index MAIN

@node MAIN "New material, sorted by category"

		 R E C E N T    S U B M I S S I O N S

Material on FreshFish is classified into categories such as demos, games,
music, pictures, etc.  Click on one of the category names below to access
material in that classification:


EOF

# Generate a list of categories.

for i in `cat $tmp2`
do
	desc=`grep "^$i" <Categories | sed "s:^$i[ 	]*::"`
	printf "  @{\" %-4s \" link $i-INDEX}  $desc\n" $i
done

# Finish off the root node.

cat <<EOF


Click @{"here" system "run >nil: execute $volname:Tools/scripts/SearchAPI $volname:New/New.api"} to search all the product info files in the "new" section of
this CD for a simple string (case independent) or @{"regular expression" link $volname:README.guide/REGEXP} and
access all material found.  Please be patient since this may take from 10
seconds to over a minute, depending upon your hardware configuration.
Future releases will greatly reduce this time.
@endnode
EOF


### Now build a node for each of the subdirectories.

for i in `cat $tmp2`
do
cat <<EOF
@node $i-INDEX "Index of subdirectory: $i"

To run a program, view a picture, etc click on the name field.
For information about other versions click on the version field.
For additional information click on the description field.
If an entry occurs more than once, it simply means that there is
more than one location on this CD where the material can be found.

Click @{"here" system "run >nil: execute $volname:Tools/scripts/SearchAPI $volname:New/New.api"} to search all the product info files in the "new" section of
this CD for a simple string (case independent) or @{"regular expression" link $volname:README.guide/REGEXP} and
access all material found.  Please be patient since this may take from 10
seconds to over a minute, depending upon your hardware configuration.
Future releases will greatly reduce this time.


EOF

	# Generate a list of product info files with this particular aminet-dir field.

	pitool <$1 -b -F "@%A@%i\n" -f - - | grep "@$i/.*@" | sed "s:@.*@::" >$tmp3

	# Sort the list by the name field.

	pitool <$tmp3 -b -F "@%N@%i\n" -f - - | sort -f | sed -e "s:@.*@::" >$tmp4

	# Generate the amigaguide entry for each product in this name sorted list.

	pitool <$tmp4 -b -F "@{\" %-18.18N \" system \"run >nil: execute $volname:tools/scripts/RunDotExecute %i\"}@{\" %8.8V \" link Find-Other-Versions}@{\" %-40.40S \" link %N-%V}\n" -f - -

	# Finish off the node for this subcategory.

	echo "@endnode"
done

### Build a dummy Find-Other-Versions node for now.

echo "@node Find-Other-Versions"
echo "The feature to locate information about other versions is currently unimplemented."
echo "@endnode"

### Now build the full contents node for each of the original product
### info files.

pitool <$1 -f - -b -F "@node %N-%V \"%S\"\n\n%N    %V    %S\n\n%d\n\nAuthor: %a\nPath: %P\n\n@endnode\n\n" -

### All done, clean up.

rm -f $tmp1 $tmp2 $tmp3 $tmp4
